@@ -386,7 +386,8 @@ class Client:
 
 		elif CCC == (44, 1): # Bulle switching
 			timestamp = packet.read32()
-			player_id = packet.read32()
+			uid = packet.read32()
+			pid = packet.read32()
 			bulle_ip = packet.readUTF()
 			ports = packet.readUTF().split('-')
 
@@ -395,7 +396,7 @@ class Client:
 
 			self.bulle = Connection('bulle', self, self.loop)
 			await self.bulle.connect(bulle_ip, random.choice(ports))
-			await self.bulle.send(Packet.new(*CCC).write32(timestamp).write32(player_id))
+			await self.bulle.send(Packet.new(44, 1).write32(timestamp).write32(uid).write32(pid))
 
 		elif CCC == (44, 22): # Fingerprint offset changed
 			connection.fingerprint = packet.read8()
@@ -865,7 +866,7 @@ class Client:
 		await self.sendHandshake()
 		await self.locale.load()
 
-	async def login(self, username, password, encrypted=True, room='1'):
+	async def login(self, username, password, encrypted=True, room='*aiotfm'):
 		"""|coro|
 		Log in the game.
 
@@ -1026,7 +1027,7 @@ class Client:
 		:param emote: :class:`int` the emote's id.
 		:param flag: Optional[:class:`str`] the flag for the emote id 10. Defaults to 'be'.
 		"""
-		packet = Packet.new(8, 1).write8(id).write32(0)
+		packet = Packet.new(8, 1).write8(emote).write32(0)
 		if emote == 10:
 			packet.writeString(flag)
 
@@ -1041,7 +1042,7 @@ class Client:
 		if smiley < 0 or smiley > 9:
 			raise AiotfmException('Invalid smiley id')
 
-		packet = Packet.new(8, 5).write8(smiley).write32(0)
+		packet = Packet.new(8, 5).write8(smiley)
 
 		await self.bulle.send(packet)
 
