@@ -1,6 +1,6 @@
 from aiotfm.utils.shakikoo import shakikoo
 from aiotfm.utils.date import Date
-from aiotfm.utils.get_keys import get_keys
+from aiotfm.utils.get_keys import get_keys, Keys
 from aiotfm.utils.locale import Translation, Locale
 
-__all__ = ['shakikoo', 'Date', 'get_keys', 'Translation', 'Locale']
\ No newline at end of file
+__all__ = ['shakikoo', 'Date', 'get_keys', 'Translation', 'Locale', 'Keys']
\ No newline at end of file
